/****************************************************************************
** Meta object code from reading C++ file 'decorationbutton.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../aurorae-6.6.4/v2/decorationbutton.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Aurorae16DecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::DecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::DecorationButton",
        "parentHoveredChanged",
        "",
        "hovered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'parentHoveredChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecorationButton, qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::DecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<KDecoration3::DecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::DecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecorationButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->parentHoveredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::parentHoveredChanged, 0))
            return;
    }
}

const QMetaObject *Aurorae::DecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::DecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae16DecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return KDecoration3::DecorationButton::qt_metacast(_clname);
}

int Aurorae::DecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDecoration3::DecorationButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Aurorae::DecorationButton::parentHoveredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::SvgDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::SvgDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SvgDecorationButton, qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::SvgDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::SvgDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SvgDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::SvgDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::SvgDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae19SvgDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return DecorationButton::qt_metacast(_clname);
}

int Aurorae::SvgDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::IconDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::IconDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IconDecorationButton, qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::IconDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::IconDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::IconDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::IconDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20IconDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return DecorationButton::qt_metacast(_clname);
}

int Aurorae::IconDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::CloseDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::CloseDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CloseDecorationButton, qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::CloseDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::CloseDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CloseDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::CloseDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::CloseDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21CloseDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::CloseDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::MaximizeDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::MaximizeDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MaximizeDecorationButton, qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::MaximizeDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::MaximizeDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MaximizeDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::MaximizeDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::MaximizeDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MaximizeDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return DecorationButton::qt_metacast(_clname);
}

int Aurorae::MaximizeDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::MinimizeDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::MinimizeDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MinimizeDecorationButton, qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::MinimizeDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::MinimizeDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MinimizeDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::MinimizeDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::MinimizeDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae24MinimizeDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::MinimizeDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::KeepAboveDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::KeepAboveDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeepAboveDecorationButton, qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::KeepAboveDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::KeepAboveDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeepAboveDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::KeepAboveDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::KeepAboveDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepAboveDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::KeepAboveDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::KeepBelowDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::KeepBelowDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeepBelowDecorationButton, qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::KeepBelowDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::KeepBelowDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeepBelowDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::KeepBelowDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::KeepBelowDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae25KeepBelowDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::KeepBelowDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::OnAllDesktopsDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::OnAllDesktopsDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OnAllDesktopsDecorationButton, qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::OnAllDesktopsDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::OnAllDesktopsDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OnAllDesktopsDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::OnAllDesktopsDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::OnAllDesktopsDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae29OnAllDesktopsDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::OnAllDesktopsDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::HelpDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::HelpDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HelpDecorationButton, qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::HelpDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::HelpDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HelpDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::HelpDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::HelpDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20HelpDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::HelpDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::ShadeDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::ShadeDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShadeDecorationButton, qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::ShadeDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::ShadeDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShadeDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::ShadeDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::ShadeDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae21ShadeDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::ShadeDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::MenuDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::MenuDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MenuDecorationButton, qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::MenuDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::MenuDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MenuDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::MenuDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::MenuDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae20MenuDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::MenuDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::FallbackMenuDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::FallbackMenuDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FallbackMenuDecorationButton, qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::FallbackMenuDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<IconDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::FallbackMenuDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FallbackMenuDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::FallbackMenuDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::FallbackMenuDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae28FallbackMenuDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return IconDecorationButton::qt_metacast(_clname);
}

int Aurorae::FallbackMenuDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IconDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::AppMenuDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::AppMenuDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppMenuDecorationButton, qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::AppMenuDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<SvgDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::AppMenuDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppMenuDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::AppMenuDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::AppMenuDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae23AppMenuDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return SvgDecorationButton::qt_metacast(_clname);
}

int Aurorae::AppMenuDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SvgDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::FallbackAppMenuDecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::FallbackAppMenuDecorationButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FallbackAppMenuDecorationButton, qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::FallbackAppMenuDecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<IconDecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::FallbackAppMenuDecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FallbackAppMenuDecorationButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::FallbackAppMenuDecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::FallbackAppMenuDecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae31FallbackAppMenuDecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return IconDecorationButton::qt_metacast(_clname);
}

int Aurorae::FallbackAppMenuDecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IconDecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7Aurorae12SpacerButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::SpacerButton::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::SpacerButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpacerButton, qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::SpacerButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DecorationButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>.metaTypes,
    nullptr
} };

void Aurorae::SpacerButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpacerButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::SpacerButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::SpacerButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12SpacerButtonE_t>.strings))
        return static_cast<void*>(this);
    return DecorationButton::qt_metacast(_clname);
}

int Aurorae::SpacerButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DecorationButton::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
