/****************************************************************************
** Meta object code from reading C++ file 'auroraetheme.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../aurorae-6.6.4/v1/lib/auroraetheme.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'auroraetheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::AuroraeTheme::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::AuroraeTheme",
        "themeChanged",
        "",
        "buttonSizesChanged",
        "borderSizesChanged",
        "loadTheme",
        "name",
        "borderLeft",
        "borderRight",
        "borderTop",
        "borderBottom",
        "borderLeftMaximized",
        "borderRightMaximized",
        "borderTopMaximized",
        "borderBottomMaximized",
        "paddingLeft",
        "paddingRight",
        "paddingTop",
        "paddingBottom",
        "themeName",
        "buttonHeight",
        "buttonWidth",
        "buttonWidthMinimize",
        "buttonWidthMaximizeRestore",
        "buttonWidthClose",
        "buttonWidthAllDesktops",
        "buttonWidthKeepAbove",
        "buttonWidthKeepBelow",
        "buttonWidthShade",
        "buttonWidthHelp",
        "buttonWidthMenu",
        "buttonWidthAppMenu",
        "buttonSpacing",
        "buttonMarginTop",
        "buttonMarginTopMaximized",
        "explicitButtonSpacer",
        "buttonSizeFactor",
        "animationTime",
        "titleEdgeLeft",
        "titleEdgeRight",
        "titleEdgeTop",
        "titleEdgeLeftMaximized",
        "titleEdgeRightMaximized",
        "titleEdgeTopMaximized",
        "titleBorderRight",
        "titleBorderLeft",
        "titleHeight",
        "decorationPath",
        "minimizeButtonPath",
        "maximizeButtonPath",
        "restoreButtonPath",
        "closeButtonPath",
        "allDesktopsButtonPath",
        "keepAboveButtonPath",
        "keepBelowButtonPath",
        "shadeButtonPath",
        "helpButtonPath",
        "appMenuButtonPath",
        "activeTextColor",
        "QColor",
        "inactiveTextColor",
        "horizontalAlignment",
        "Qt::Alignment",
        "verticalAlignment"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'buttonSizesChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderSizesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadTheme'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'borderLeft'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderRight'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderTop'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderBottom'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderLeftMaximized'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderRightMaximized'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderTopMaximized'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'borderBottomMaximized'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'paddingLeft'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'paddingRight'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'paddingTop'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'paddingBottom'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'themeName'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'buttonHeight'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidth'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthMinimize'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthMaximizeRestore'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthClose'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthAllDesktops'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthKeepAbove'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthKeepBelow'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthShade'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthHelp'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthMenu'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonWidthAppMenu'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonSpacing'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonMarginTop'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonMarginTopMaximized'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'explicitButtonSpacer'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'buttonSizeFactor'
        QtMocHelpers::PropertyData<qreal>(36, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'animationTime'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeLeft'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeRight'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeTop'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeLeftMaximized'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeRightMaximized'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleEdgeTopMaximized'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleBorderRight'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleBorderLeft'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'titleHeight'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'decorationPath'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'minimizeButtonPath'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'maximizeButtonPath'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'restoreButtonPath'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'closeButtonPath'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'allDesktopsButtonPath'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'keepAboveButtonPath'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'keepBelowButtonPath'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'shadeButtonPath'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'helpButtonPath'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'appMenuButtonPath'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'activeTextColor'
        QtMocHelpers::PropertyData<QColor>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'inactiveTextColor'
        QtMocHelpers::PropertyData<QColor>(60, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'horizontalAlignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'verticalAlignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(63, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AuroraeTheme, qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::AuroraeTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>.metaTypes,
    nullptr
} };

void Aurorae::AuroraeTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AuroraeTheme *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->themeChanged(); break;
        case 1: _t->buttonSizesChanged(); break;
        case 2: _t->borderSizesChanged(); break;
        case 3: _t->loadTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AuroraeTheme::*)()>(_a, &AuroraeTheme::themeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuroraeTheme::*)()>(_a, &AuroraeTheme::buttonSizesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuroraeTheme::*)()>(_a, &AuroraeTheme::borderSizesChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->leftBorder(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->rightBorder(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->topBorder(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->bottomBorder(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->leftBorderMaximized(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->rightBorderMaximized(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->topBorderMaximized(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->bottomBorderMaximized(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->paddingLeft(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->paddingRight(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->paddingTop(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->paddingBottom(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->themeName(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->buttonHeight(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->buttonWidth(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->buttonWidthMinimize(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->buttonWidthMaximizeRestore(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->buttonWidthClose(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->buttonWidthAllDesktops(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->buttonWidthKeepAbove(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->buttonWidthKeepBelow(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->buttonWidthShade(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->buttonWidthHelp(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->buttonWidthMenu(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->buttonWidthAppMenu(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->buttonSpacing(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->buttonMarginTop(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->buttonMarginTopMaximized(); break;
        case 28: *reinterpret_cast<int*>(_v) = _t->explicitButtonSpacer(); break;
        case 29: *reinterpret_cast<qreal*>(_v) = _t->buttonSizeFactor(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->animationTime(); break;
        case 31: *reinterpret_cast<int*>(_v) = _t->titleEdgeLeft(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->titleEdgeRight(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->titleEdgeTop(); break;
        case 34: *reinterpret_cast<int*>(_v) = _t->titleEdgeLeftMaximized(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->titleEdgeRightMaximized(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->titleEdgeTopMaximized(); break;
        case 37: *reinterpret_cast<int*>(_v) = _t->titleBorderRight(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->titleBorderLeft(); break;
        case 39: *reinterpret_cast<int*>(_v) = _t->titleHeight(); break;
        case 40: *reinterpret_cast<QString*>(_v) = _t->decorationPath(); break;
        case 41: *reinterpret_cast<QString*>(_v) = _t->minimizeButtonPath(); break;
        case 42: *reinterpret_cast<QString*>(_v) = _t->maximizeButtonPath(); break;
        case 43: *reinterpret_cast<QString*>(_v) = _t->restoreButtonPath(); break;
        case 44: *reinterpret_cast<QString*>(_v) = _t->closeButtonPath(); break;
        case 45: *reinterpret_cast<QString*>(_v) = _t->allDesktopsButtonPath(); break;
        case 46: *reinterpret_cast<QString*>(_v) = _t->keepAboveButtonPath(); break;
        case 47: *reinterpret_cast<QString*>(_v) = _t->keepBelowButtonPath(); break;
        case 48: *reinterpret_cast<QString*>(_v) = _t->shadeButtonPath(); break;
        case 49: *reinterpret_cast<QString*>(_v) = _t->helpButtonPath(); break;
        case 50: *reinterpret_cast<QString*>(_v) = _t->appMenuButtonPath(); break;
        case 51: *reinterpret_cast<QColor*>(_v) = _t->activeTextColor(); break;
        case 52: *reinterpret_cast<QColor*>(_v) = _t->inactiveTextColor(); break;
        case 53: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 54: *reinterpret_cast<Qt::Alignment*>(_v) = _t->verticalAlignment(); break;
        default: break;
        }
    }
}

const QMetaObject *Aurorae::AuroraeTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::AuroraeTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae12AuroraeThemeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Aurorae::AuroraeTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void Aurorae::AuroraeTheme::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Aurorae::AuroraeTheme::buttonSizesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Aurorae::AuroraeTheme::borderSizesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
