/*
    SPDX-FileCopyrightText: 2025 Vlad Zahorodnii <vlad.zahorodnii@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "logging.h"

Q_LOGGING_CATEGORY(AURORAE, "aurorae", QtWarningMsg)
