/****************************************************************************
** Meta object code from reading C++ file 'decorationoptions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../aurorae-6.6.4/v1/decorationoptions.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationoptions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::DecorationOptions::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::DecorationOptions",
        "colorsChanged",
        "",
        "fontChanged",
        "decorationChanged",
        "titleButtonsChanged",
        "slotActiveChanged",
        "deco",
        "KDecoration3::Decoration*",
        "titleBarColor",
        "QColor",
        "titleBarBlendColor",
        "fontColor",
        "buttonColor",
        "borderColor",
        "resizeHandleColor",
        "titleFont",
        "QFont",
        "titleButtonsLeft",
        "QList<int>",
        "titleButtonsRight",
        "mousePressAndHoldInterval",
        "BorderSize",
        "BorderNone",
        "BorderNoSides",
        "BorderTiny",
        "BorderNormal",
        "BorderLarge",
        "BorderVeryLarge",
        "BorderHuge",
        "BorderVeryHuge",
        "BorderOversized",
        "DecorationButton",
        "DecorationButtonNone",
        "DecorationButtonMenu",
        "DecorationButtonApplicationMenu",
        "DecorationButtonOnAllDesktops",
        "DecorationButtonQuickHelp",
        "DecorationButtonMinimize",
        "DecorationButtonMaximizeRestore",
        "DecorationButtonClose",
        "DecorationButtonKeepAbove",
        "DecorationButtonKeepBelow",
        "DecorationButtonShade",
        "DecorationButtonResize",
        "DecorationButtonExplicitSpacer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decorationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleButtonsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActiveChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'deco'
        QtMocHelpers::PropertyData<KDecoration3::Decoration*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'titleBarColor'
        QtMocHelpers::PropertyData<QColor>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'titleBarBlendColor'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'fontColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'buttonColor'
        QtMocHelpers::PropertyData<QColor>(13, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'resizeHandleColor'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'titleFont'
        QtMocHelpers::PropertyData<QFont>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'titleButtonsLeft'
        QtMocHelpers::PropertyData<QList<int>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'titleButtonsRight'
        QtMocHelpers::PropertyData<QList<int>>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'mousePressAndHoldInterval'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BorderSize'
        QtMocHelpers::EnumData<enum BorderSize>(22, 22, QMC::EnumFlags{}).add({
            {   23, BorderSize::BorderNone },
            {   24, BorderSize::BorderNoSides },
            {   25, BorderSize::BorderTiny },
            {   26, BorderSize::BorderNormal },
            {   27, BorderSize::BorderLarge },
            {   28, BorderSize::BorderVeryLarge },
            {   29, BorderSize::BorderHuge },
            {   30, BorderSize::BorderVeryHuge },
            {   31, BorderSize::BorderOversized },
        }),
        // enum 'DecorationButton'
        QtMocHelpers::EnumData<enum DecorationButton>(32, 32, QMC::EnumFlags{}).add({
            {   33, DecorationButton::DecorationButtonNone },
            {   34, DecorationButton::DecorationButtonMenu },
            {   35, DecorationButton::DecorationButtonApplicationMenu },
            {   36, DecorationButton::DecorationButtonOnAllDesktops },
            {   37, DecorationButton::DecorationButtonQuickHelp },
            {   38, DecorationButton::DecorationButtonMinimize },
            {   39, DecorationButton::DecorationButtonMaximizeRestore },
            {   40, DecorationButton::DecorationButtonClose },
            {   41, DecorationButton::DecorationButtonKeepAbove },
            {   42, DecorationButton::DecorationButtonKeepBelow },
            {   43, DecorationButton::DecorationButtonShade },
            {   44, DecorationButton::DecorationButtonResize },
            {   45, DecorationButton::DecorationButtonExplicitSpacer },
        }),
    };
    return QtMocHelpers::metaObjectData<DecorationOptions, qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::DecorationOptions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>.metaTypes,
    nullptr
} };

void Aurorae::DecorationOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecorationOptions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorsChanged(); break;
        case 1: _t->fontChanged(); break;
        case 2: _t->decorationChanged(); break;
        case 3: _t->titleButtonsChanged(); break;
        case 4: _t->slotActiveChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecorationOptions::*)()>(_a, &DecorationOptions::colorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationOptions::*)()>(_a, &DecorationOptions::fontChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationOptions::*)()>(_a, &DecorationOptions::decorationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationOptions::*)()>(_a, &DecorationOptions::titleButtonsChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration3::Decoration* >(); break;
        case 9:
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KDecoration3::Decoration**>(_v) = _t->decoration(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->titleBarColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->titleBarBlendColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->fontColor(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->buttonColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->resizeHandleColor(); break;
        case 7: *reinterpret_cast<QFont*>(_v) = _t->titleFont(); break;
        case 8: *reinterpret_cast<QList<int>*>(_v) = _t->titleButtonsLeft(); break;
        case 9: *reinterpret_cast<QList<int>*>(_v) = _t->titleButtonsRight(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->mousePressAndHoldInterval(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDecoration(*reinterpret_cast<KDecoration3::Decoration**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Aurorae::DecorationOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::DecorationOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae17DecorationOptionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Aurorae::DecorationOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Aurorae::DecorationOptions::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Aurorae::DecorationOptions::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Aurorae::DecorationOptions::decorationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Aurorae::DecorationOptions::titleButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN7Aurorae7BordersE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::Borders::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae7BordersE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::Borders",
        "leftChanged",
        "",
        "rightChanged",
        "topChanged",
        "bottomChanged",
        "setAllBorders",
        "value",
        "setBorders",
        "setSideBorders",
        "setTitle",
        "left",
        "right",
        "top",
        "bottom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'leftChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAllBorders'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setBorders'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setSideBorders'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'left'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'right'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'top'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'bottom'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Borders, qt_meta_tag_ZN7Aurorae7BordersE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::Borders::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae7BordersE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae7BordersE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae7BordersE_t>.metaTypes,
    nullptr
} };

void Aurorae::Borders::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Borders *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->leftChanged(); break;
        case 1: _t->rightChanged(); break;
        case 2: _t->topChanged(); break;
        case 3: _t->bottomChanged(); break;
        case 4: _t->setAllBorders((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setBorders((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setSideBorders((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Borders::*)()>(_a, &Borders::leftChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Borders::*)()>(_a, &Borders::rightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Borders::*)()>(_a, &Borders::topChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Borders::*)()>(_a, &Borders::bottomChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->left(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->right(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->top(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->bottom(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLeft(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setRight(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setTop(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setBottom(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Aurorae::Borders::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::Borders::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae7BordersE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Aurorae::Borders::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Aurorae::Borders::leftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Aurorae::Borders::rightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Aurorae::Borders::topChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Aurorae::Borders::bottomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
