/****************************************************************************
** Meta object code from reading C++ file 'colorhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../aurorae-6.6.4/v1/colorhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'colorhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ColorHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorHelper::qt_create_metaobjectdata<qt_meta_tag_ZN11ColorHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorHelper",
        "shade",
        "QColor",
        "",
        "color",
        "ShadeRole",
        "role",
        "contrast",
        "multiplyAlpha",
        "alpha",
        "background",
        "active",
        "BackgroundRole",
        "foreground",
        "ForegroundRole",
        "LightShade",
        "MidlightShade",
        "MidShade",
        "DarkShade",
        "ShadowShade",
        "NormalBackground",
        "AlternateBackground",
        "ActiveBackground",
        "LinkBackground",
        "VisitedBackground",
        "NegativeBackground",
        "NeutralBackground",
        "PositiveBackground",
        "NormalText",
        "InactiveText",
        "ActiveText",
        "LinkText",
        "VisitedText",
        "NegativeText",
        "NeutralText",
        "PositiveText"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, enum ShadeRole)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, enum ShadeRole, qreal)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::QReal, 7 },
        }}),
        // Method 'multiplyAlpha'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 }, { QMetaType::QReal, 9 },
        }}),
        // Method 'background'
        QtMocHelpers::MethodData<QColor(bool, enum BackgroundRole) const>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 6 },
        }}),
        // Method 'background'
        QtMocHelpers::MethodData<QColor(bool) const>(10, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::Bool, 11 },
        }}),
        // Method 'foreground'
        QtMocHelpers::MethodData<QColor(bool, enum ForegroundRole) const>(13, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 14, 6 },
        }}),
        // Method 'foreground'
        QtMocHelpers::MethodData<QColor(bool) const>(13, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::Bool, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'contrast'
        QtMocHelpers::PropertyData<qreal>(7, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ShadeRole'
        QtMocHelpers::EnumData<enum ShadeRole>(5, 5, QMC::EnumFlags{}).add({
            {   15, ShadeRole::LightShade },
            {   16, ShadeRole::MidlightShade },
            {   17, ShadeRole::MidShade },
            {   18, ShadeRole::DarkShade },
            {   19, ShadeRole::ShadowShade },
        }),
        // enum 'BackgroundRole'
        QtMocHelpers::EnumData<enum BackgroundRole>(12, 12, QMC::EnumFlags{}).add({
            {   20, BackgroundRole::NormalBackground },
            {   21, BackgroundRole::AlternateBackground },
            {   22, BackgroundRole::ActiveBackground },
            {   23, BackgroundRole::LinkBackground },
            {   24, BackgroundRole::VisitedBackground },
            {   25, BackgroundRole::NegativeBackground },
            {   26, BackgroundRole::NeutralBackground },
            {   27, BackgroundRole::PositiveBackground },
        }),
        // enum 'ForegroundRole'
        QtMocHelpers::EnumData<enum ForegroundRole>(14, 14, QMC::EnumFlags{}).add({
            {   28, ForegroundRole::NormalText },
            {   29, ForegroundRole::InactiveText },
            {   30, ForegroundRole::ActiveText },
            {   31, ForegroundRole::LinkText },
            {   32, ForegroundRole::VisitedText },
            {   33, ForegroundRole::NegativeText },
            {   34, ForegroundRole::NeutralText },
            {   35, ForegroundRole::PositiveText },
        }),
    };
    return QtMocHelpers::metaObjectData<ColorHelper, qt_meta_tag_ZN11ColorHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ColorHelperE_t>.metaTypes,
    nullptr
} };

void ColorHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ShadeRole>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 1: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ShadeRole>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 2: { QColor _r = _t->multiplyAlpha((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 3: { QColor _r = _t->background((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum BackgroundRole>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { QColor _r = _t->background((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { QColor _r = _t->foreground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ForegroundRole>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 6: { QColor _r = _t->foreground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->contrast(); break;
        default: break;
        }
    }
}

const QMetaObject *ColorHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ColorHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
