/****************************************************************************
** Meta object code from reading C++ file 'aurorae.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../aurorae-6.6.4/v1/aurorae.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'aurorae.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Aurorae10DecorationE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::Decoration::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae10DecorationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::Decoration",
        "configChanged",
        "",
        "init",
        "installTitleItem",
        "QQuickItem*",
        "item",
        "updateShadow",
        "updateBlur",
        "readConfig",
        "QVariant",
        "key",
        "defaultValue",
        "client",
        "KDecoration3::DecoratedWindow*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'installTitleItem'
        QtMocHelpers::SlotData<void(QQuickItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateShadow'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateBlur'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'readConfig'
        QtMocHelpers::MethodData<QVariant(const QString &, const QVariant &)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 10, 12 },
        }}),
        // Method 'readConfig'
        QtMocHelpers::MethodData<QVariant(const QString &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 10, {{
            { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'client'
        QtMocHelpers::PropertyData<KDecoration3::DecoratedWindow*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'item'
        QtMocHelpers::PropertyData<QQuickItem*>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Decoration, qt_meta_tag_ZN7Aurorae10DecorationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::Decoration::staticMetaObject = { {
    QMetaObject::SuperData::link<KDecoration3::Decoration::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae10DecorationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae10DecorationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae10DecorationE_t>.metaTypes,
    nullptr
} };

void Aurorae::Decoration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Decoration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: { bool _r = _t->init();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->installTitleItem((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 3: _t->updateShadow(); break;
        case 4: _t->updateBlur(); break;
        case 5: { QVariant _r = _t->readConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariant _r = _t->readConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::configChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KDecoration3::DecoratedWindow**>(_v) = _t->window(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->item(); break;
        default: break;
        }
    }
}

const QMetaObject *Aurorae::Decoration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::Decoration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae10DecorationE_t>.strings))
        return static_cast<void*>(this);
    return KDecoration3::Decoration::qt_metacast(_clname);
}

int Aurorae::Decoration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDecoration3::Decoration::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Aurorae::Decoration::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN7Aurorae13ThemeProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto Aurorae::ThemeProvider::qt_create_metaobjectdata<qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Aurorae::ThemeProvider"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ThemeProvider, qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Aurorae::ThemeProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<KDecoration3::DecorationThemeProvider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>.metaTypes,
    nullptr
} };

void Aurorae::ThemeProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThemeProvider *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Aurorae::ThemeProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Aurorae::ThemeProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Aurorae13ThemeProviderE_t>.strings))
        return static_cast<void*>(this);
    return KDecoration3::DecorationThemeProvider::qt_metacast(_clname);
}

int Aurorae::ThemeProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDecoration3::DecorationThemeProvider::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
